@@ -39,8 +39,6 @@ sub action {
 
   my $filename = substr($request->uri()->path(), 1);
 
-#  print "* processing $filename\n";
-
   return unless -e $templatedir . $filename && -r _;
 
   $tt->process($filename, $session, \$output) || ($output = $tt->error);
@@ -56,5 +54,36 @@ sub action {
 
 1;
 
+__END__
+
+=head1 NAME
+
+Hangman::Generator - A templated output generator for hangman
+
+=head1 DESCRIPTION
+
+C<Hangman::Generator> is a templated output generator for hangman. The
+session is passed to a Template Toolkit template, which generates
+output, and the code then generates a response.
+
+Note that it explicity checks if the request is meant for the
+application, rather than an image, by checking for "index.html" and
+seeing if it can read the template file.
+
+The template used is "templates/index.html" so investigate that to
+understand the clear seperation between logic and presentation present
+in this example hangman game.
+
+=head1 AUTHOR
+
+Leon Brocard <leon@fotango.com>
+
+=head1 COPYRIGHT
+
+Copyright (C) 2001, Fotango Ltd.
+
+This module is free software; you can redistribute it or modify it
+under the same terms as Perl itself.
+
 
 
