@@ -41,4 +41,34 @@ sub action {
 
 1;
 
+__END__
 
+=head1 NAME
+
+OpenFrame::Slot::NoImages - decline serving image files
+
+=head1 SYNOPSIS
+
+  # as part of the SLOTS entry in OpenFrame::Config:
+  {
+  dispatch => 'Local',
+  name     => 'OpenFrame::Slot::NoImages',
+  },
+
+=head1 DESCRIPTION
+
+C<OpenFrame::Slot::NoImages> is an OpenFrame slot that declines
+handling images. It takes the path from the
+C<OpenFrame::AbstractRequest> and returns a declining response if the
+file is not a .html file.
+
+=head1 AUTHOR
+
+James A. Duncan <jduncan@fotango.com>
+
+=head1 COPYRIGHT
+
+Copyright (C) 2001, Fotango Ltd.
+
+This module is free software; you can redistribute it or modify it
+under the same terms as Perl itself.
