@@ -6,27 +6,26 @@ use warnings::register;
 use Template;
 use OpenFrame::Config;
 use OpenFrame::AbstractResponse;
+use OpenFrame::Constants;
 
 sub what {
   return ['OpenFrame::Session', 'OpenFrame::AbstractRequest', 'OpenFrame::AbstractCookie'];
 }
 
 sub action {
-  my $class   = shift;
-  my $session = shift;
-  my $request = shift;
-  my $cookie  = shift;
+  my $class     = shift;
+  my $config    = shift;
+  my $session   = shift;
+  my $request   = shift;
+  my $cookietin = shift;
 
   my $output;
 
-  $output .= "Here is the output of SimpleGenerator for ";
-  $output .= $request->getURI()->path();
-  $output .= "\n";
-  $output .= $session->{application}->{myapp}->{message};
-
   my $response = OpenFrame::AbstractResponse->new();
-  $response->setMessage($output);
-  $response->setMessageCode(ofOK);
+  $response->message($session);
+  $response->code(ofOK);
+  $response->mimetype('openframe/session');
+  $response->cookies($cookietin);
 
   return $response;
 }
